@@ -1,9 +1,9 @@
 """An http toolkit built on fastapi."""
 
-from brewing.http.viewset import ViewSet as ViewSet
+from brewing.http.viewset import ViewSet as ViewSet, ViewsetOptions as ViewsetOptions
 from brewing.http.path import self
 from brewing.http.asgi import BrewingHTTP as BrewingHTTP
 from fastapi import status as status
 
 
-__all__ = ["ViewSet", "BrewingHTTP", "status", "self"]
+__all__ = ["ViewSet", "ViewsetOptions", "BrewingHTTP", "status", "self"]
